@@ -16,7 +16,7 @@ import datetime
 import re
 
 from openpyxl.compat import NUMERIC_TYPES
-from openpyxl.compat import lru_cache, range
+from openpyxl.compat import lru_cache, range, deprecated
 from openpyxl.units import (
     DEFAULT_ROW_HEIGHT,
     DEFAULT_COLUMN_WIDTH
@@ -35,7 +35,6 @@ from openpyxl.exceptions import (
 from openpyxl.units import points_to_pixels
 from openpyxl.styles import is_date_format
 from openpyxl.styles import numbers
-#from openpyxl.styles import NumberFormat
 
 
 # package imports
@@ -239,14 +238,19 @@ class Cell(object):
         self._value = value
         self.data_type = data_type
 
+
+    @deprecated("Method is private")
     def bind_value(self, value):
+        self._bind_value(value)
+
+
+    def _bind_value(self, value):
         """Given a value, infer the correct data type"""
         if not isinstance(value, KNOWN_TYPES):
             raise ValueError("Cannot convert {0} to Excel".format(value))
 
         self.data_type = self.TYPE_NUMERIC
-        #if value is None:
-            #value = ''
+
         if isinstance(value, bool):
             self.data_type = self.TYPE_BOOL
         elif isinstance(value, NUMERIC_TYPES):
@@ -263,11 +267,16 @@ class Cell(object):
             elif value in self.ERROR_CODES:
                 self.data_type = self.TYPE_ERROR
             elif self.guess_types:
-                value = self.infer_value(value)
+                value = self._infer_value(value)
         self.set_explicit_value(value, self.data_type)
 
 
+    @deprecated("Method is private")
     def infer_value(self, value):
+        return self._infer_value(value)
+
+
+    def _infer_value(self, value):
         """Given a string, infer type and formatting options."""
         if not isinstance(value, unicode):
             value = str(value)
@@ -343,14 +352,14 @@ class Cell(object):
             ':rtype: depends on the value (string, float, int or '
             ':class:`datetime.datetime`)'"""
         value = self._value
-        if self.is_date():
+        if self.is_date() and value is not None:
             value = from_excel(value, self.base_date)
         return value
 
     @value.setter
     def value(self, value):
         """Set the value and infer type and display options."""
-        self.bind_value(value)
+        self._bind_value(value)
 
     @property
     def internal_value(self):
